PyR3 package
============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   PyR3.contrib
   PyR3.factory
   PyR3.shortcut

Submodules
----------

PyR3.install\_bpy module
------------------------

.. automodule:: PyR3.install_bpy
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: PyR3
   :members:
   :undoc-members:
   :show-inheritance:
